==> gradle-src-8.14.1-1-any.pkg.tar.zst: usr/share/java/gradle/src/tooling-api/org/gradle/tooling/events/problems/internal/DefaultSingleProblemEvent.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.events.problems.internal;

import org.gradle.api.NonNullApi;
import org.gradle.tooling.events.OperationDescriptor;
import org.gradle.tooling.events.internal.BaseProgressEvent;
import org.gradle.tooling.events.problems.Problem;
import org.gradle.tooling.events.problems.SingleProblemEvent;

import javax.annotation.Nullable;

@NonNullApi
public class DefaultSingleProblemEvent extends BaseProgressEvent implements SingleProblemEvent {
    private final Problem problem;

    public DefaultSingleProblemEvent(
        long eventTime,
        @Nullable OperationDescriptor problemDescriptor,
        Problem problem
    ) {
        super(eventTime, problemDescriptor == null ? "<null>" : problemDescriptor.getDisplayName(), problemDescriptor);
        this.problem = problem;
    }

    @Override
    public Problem getProblem() {
        return problem;
    }
}

==> gradle-src-9.2.1-1-any.pkg.tar.zst: usr/share/java/gradle/src/tooling-api/org/gradle/tooling/events/problems/internal/DefaultSingleProblemEvent.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.events.problems.internal;

import org.gradle.tooling.events.OperationDescriptor;
import org.gradle.tooling.events.internal.BaseProgressEvent;
import org.gradle.tooling.events.problems.Problem;
import org.gradle.tooling.events.problems.SingleProblemEvent;
import org.jspecify.annotations.NullMarked;
import org.jspecify.annotations.Nullable;

@NullMarked
public class DefaultSingleProblemEvent extends BaseProgressEvent implements SingleProblemEvent {
    private final Problem problem;

    public DefaultSingleProblemEvent(
        long eventTime,
        @Nullable OperationDescriptor problemDescriptor,
        Problem problem
    ) {
        super(eventTime, problemDescriptor == null ? "<null>" : problemDescriptor.getDisplayName(), problemDescriptor);
        this.problem = problem;
    }

    @Override
    public Problem getProblem() {
        return problem;
    }
}
